@@ -4,6 +4,7 @@ from django.views.generic import TemplateView
 from tastypie.api import Api
 
 from .api import ImageResource, ThumbnailResource, PinResource, UserResource
+from .feeds import LatestPins, LatestUserPins, LatestTagPins
 from .views import CreateImage
 
 
@@ -17,6 +18,10 @@ v1_api.register(UserResource())
 urlpatterns = patterns('',
     url(r'^api/', include(v1_api.urls, namespace='api')),
 
+    url(r'feeds/latest-pins/tag/(?P<tag>(\w|-)+)/', LatestTagPins()),
+    url(r'feeds/latest-pins/user/(?P<user>(\w|-)+)/', LatestUserPins()),
+    url(r'feeds/latest-pins/', LatestPins()),
+
     url(r'^pins/pin-form/$', TemplateView.as_view(template_name='core/pin_form.html'),
         name='pin-form'),
     url(r'^pins/create-image/$', CreateImage.as_view(), name='create-image'),
@@ -25,6 +30,8 @@ urlpatterns = patterns('',
         name='tag-pins'),
     url(r'^pins/user/(?P<user>(\w|-)+)/$', TemplateView.as_view(template_name='core/pins.html'),
         name='user-pins'),
+    url(r'^(?P<pin>\d+)/$', TemplateView.as_view(template_name='core/pins.html'),
+        name='recent-pins'),
     url(r'^$', TemplateView.as_view(template_name='core/pins.html'),
         name='recent-pins'),
 )
